Box-free virtual Ktool state for one Kennedy subagent.
Structs
- Context
- Ephemeral current state owned exclusively by one subagent run.
- Source
State - One applied managed-source snapshot and its stable virtual identity.
- State
Changes - Current state changes produced by one successful child operation.